summary refs log tree commit diff
path: root/pkgs/development/libraries/phonon
diff options
context:
space:
mode:
authorJonathan Ringer <jonringer117@gmail.com>2021-01-18 22:50:56 -0800
committerJonathan Ringer <jonringer@users.noreply.github.com>2021-01-19 01:16:25 -0800
commit9bb3fccb5b55326cb3c2c507464a8a28d44d1730 (patch)
tree9d1c0c16cce5e5dcc08115230f6412865487964b /pkgs/development/libraries/phonon
parent200bb8c977d81ebdf847d5e6839cd46cd3eb8d4d (diff)
downloadnixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.gz
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.bz2
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.lz
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.xz
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.tar.zst
nixpkgs-9bb3fccb5b55326cb3c2c507464a8a28d44d1730.zip
treewide: pkgs.pkgconfig -> pkgs.pkg-config, move pkgconfig to alias.nix
continuation of #109595

pkgconfig was aliased in 2018, however, it remained in
all-packages.nix due to its wide usage. This cleans
up the remaining references to pkgs.pkgsconfig and
moves the entry to aliases.nix.

python3Packages.pkgconfig remained unchanged because
it's the canonical name of the upstream package
on pypi.
Diffstat (limited to 'pkgs/development/libraries/phonon')
-rw-r--r--pkgs/development/libraries/phonon/backends/gstreamer.nix6
-rw-r--r--pkgs/development/libraries/phonon/backends/vlc.nix4
-rw-r--r--pkgs/development/libraries/phonon/default.nix4
3 files changed, 7 insertions, 7 deletions
diff --git a/pkgs/development/libraries/phonon/backends/vlc.nix b/pkgs/development/libraries/phonon/backends/vlc.nix
index d54ee6e5630..3dc5071ba15 100644
--- a/pkgs/development/libraries/phonon/backends/vlc.nix
+++ b/pkgs/development/libraries/phonon/backends/vlc.nix
@@ -1,4 +1,4 @@
-{ stdenv, lib, fetchurl, cmake, phonon, pkgconfig, libvlc
+{ stdenv, lib, fetchurl, cmake, phonon, pkg-config, libvlc
 , extra-cmake-modules, qttools, qtbase, qtx11extras
 , debug ? false
 }:
@@ -30,7 +30,7 @@ stdenv.mkDerivation rec {
 
   nativeBuildInputs = [
     cmake
-    pkgconfig
+    pkg-config
     qttools
     extra-cmake-modules
   ];
diff --git a/pkgs/development/libraries/phonon/default.nix b/pkgs/development/libraries/phonon/default.nix
index 85ba37a9d8a..926b8593c59 100644
--- a/pkgs/development/libraries/phonon/default.nix
+++ b/pkgs/development/libraries/phonon/default.nix
@@ -4,7 +4,7 @@
 , cmake
 , libGLU
 , libGL
-, pkgconfig
+, pkg-config
 , libpulseaudio
 , extra-cmake-modules
 , qtbase
@@ -46,7 +46,7 @@ stdenv.mkDerivation rec {
 
   nativeBuildInputs = [
     cmake
-    pkgconfig
+    pkg-config
     extra-cmake-modules
   ];
diff --git a/pkgs/development/libraries/phonon/backends/gstreamer.nix b/pkgs/development/libraries/phonon/backends/gstreamer.nix
index 5c0901596b0..c066e15a8f9 100644
--- a/pkgs/development/libraries/phonon/backends/gstreamer.nix
+++ b/pkgs/development/libraries/phonon/backends/gstreamer.nix
@@ -1,4 +1,4 @@
-{ stdenv, lib, fetchurl, cmake, gst_all_1, phonon, pkgconfig
+{ stdenv, lib, fetchurl, cmake, gst_all_1, phonon, pkg-config
 , extra-cmake-modules, qttools, qtbase, qtx11extras
 , debug ? false
 }:
@@ -38,7 +38,7 @@ stdenv.mkDerivation rec {
             gst-libav
           ]);
     in toString [
       # This flag should be picked up through pkgconfig, but it isn't.
       "-I${gst_all_1.gstreamer.dev}/lib/gstreamer-1.0/include"
 
       ''-DGST_PLUGIN_PATH_1_0="${gstPluginPaths}"''
@@ -54,7 +54,7 @@ stdenv.mkDerivation rec {
 
   nativeBuildInputs = [
     cmake
-    pkgconfig
+    pkg-config
     extra-cmake-modules
     qttools
   ];
@@ -38,7 +38,7 @@ stdenv.mkDerivation rec {
           ]);
     in toString [
-      # This flag should be picked up through pkgconfig, but it isn't.
+      # This flag should be picked up through pkg-config, but it isn't.
       "-I${gst_all_1.gstreamer.dev}/lib/gstreamer-1.0/include"
 